<?php

namespace Drupal\Tests\purge_queuer_url\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\node\Traits\ContentTypeCreationTrait;
use Drupal\Tests\node\Traits\NodeCreationTrait;

/**
 * Tests the functionality of the Url Registrar middleware.
 *
 * @group facets
 */
class UrlRegistrarTest extends BrowserTestBase {

  use ContentTypeCreationTrait;
  use NodeCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'datetime',
    'node',
    'purge_queuer_url',
  ];

  /**
   * The traffic registry object.
   *
   * @var \Drupal\purge_queuer_url\TrafficRegistryInterface
   */
  protected $registry;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->registry = \Drupal::service('purge_queuer_url.registry');

    // Enable page caching.
    $config = $this->config('system.performance');
    $config->set('cache.page.max_age', 300);
    $config->save();
  }

  /**
   * Basic test of middleware.
   */
  public function testUrlRegistrar() {
    $this->drupalCreateContentType([
      'type' => 'page',
      'name' => 'Basic page',
      'display_submitted' => FALSE,
    ]);

    $node = $this->drupalCreateNode(['type' => 'page']);
    $this->drupalGet($node->toUrl());

    $urls = $this->registry->getUrls(['node:' . $node->id()]);
    $this->assertCount(1, $urls);

    // Test that the URL is not removed when viewed by an authenticated user.
    $user = $this->drupalCreateUser();
    $this->drupalLogin($user);
    $this->drupalGet($node->toUrl());

    $urls = $this->registry->getUrls($node->getCacheTags());
    $this->assertCount(1, $urls);
  }

}
